@@ -57,4 +57,11 @@ sub test_connection {
     return %result;
 }
 
+sub generate_password {
+    my @chars = ('a' .. 'z', 'A' .. 'Z', '0' .. '9', '.', '_', '-');
+    my @p = map {$chars[ sprintf("%d", rand(scalar @chars)) ]} (1.. 6);
+
+    return join('', @p);
+}
+
 1;
